[![PyPI version](https://badge.fury.io/py/easys-ordermanager.svg)](https://badge.fury.io/py/easys-ordermanager)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/Lektor.svg)](https://pypi.org/project/easys-ordermanager/)

# EasyS order manager API

## Compatibility

### Django 4.2

Python 3.11 to 3.12
DRF 3.14 to 3.15

### Django 5.0

Python 3.11 to 3.12
DRF 3.14 to 3.15

### Django 5.1

Python 3.11 to 3.12
DRF 3.14 to 3.15
